stm32-metapac

Crates

git

Versions

stm32h563vg

Flavors

M5sear

Struct M5sear 

#[repr(transparent)]
pub struct M5sear(pub u32);
RAMCFG memory 5 ECC single error address register.

Tuple Fields

0: u32

Implementations



impl M5sear

pub const fn esea(&self) -> u32

ECC single error address When the ALE bit is set in the MxCR register, this field is updated with the address corresponding to the ECC single error.

pub const fn set_esea(&mut self, val: u32)

ECC single error address When the ALE bit is set in the MxCR register, this field is updated with the address corresponding to the ECC single error.